/*==============================================================*/
# Script FreeCommerce 
#
# Database: bd_freecommerce
#
# Script version 1.00.00
# Data: 11/08/2003
# Atualizado por: Csar Francisco de Moura Couto

/*==============================================================*/
/* Database: bd_freecommerce                                       */
/*==============================================================*/
create database if not exists bd_freecommerce;

use bd_freecommerce;


/*==============================================================*/
/* Drop existed tables                                                        */
/*==============================================================*/
drop table if exists fc_item_pedido;

drop table if exists fc_boleto_gerado;

drop table if exists fc_pedido;

drop table if exists fc_log_comprador;

drop table if exists fc_caract_produto;

drop table if exists fc_aut_compra;

drop table if exists fc_movto_estoq;

drop table if exists fc_condicao;

drop table if exists fc_produto;

drop table if exists fc_comprador;

drop table if exists fc_cidades_br;

drop table if exists fc_estados;

drop table if exists fc_parcela;

drop table if exists fc_loja;

drop table if exists fc_log_usuario;

drop table if exists fc_usuario;

drop table if exists fc_unidade_medida;

drop table if exists fc_pessoa_juridica;

drop table if exists fc_pessoa_fisica;

drop table if exists fc_pessoa;

drop table if exists fc_parcelamento;

drop table if exists fc_pais;

drop table if exists fc_moeda;

drop table if exists fc_frete_estado;

drop table if exists fc_frete;

drop table if exists fc_forma_pagamento;

drop table if exists fc_fabricante;
                            
drop table if exists fc_entidade_financeira;

drop table if exists fc_empresa;

drop table if exists fc_classe_produto;

drop table if exists fc_imagem;


/*==============================================================*/
/* Table: fc_classe_produto                                     */
/*==============================================================*/
create table if not exists fc_classe_produto
(
   cod_classe                     varchar(40)                    not null,
   des_classe                     varchar(255)                   not null,
   primary key (cod_classe)
)
type = InnoDB;      

/*==============================================================*/
/* Table: fc_empresa                                            */
/*==============================================================*/
create table if not exists fc_empresa
(
   id_empres                      int(11)                        not null AUTO_INCREMENT,
   nom_empres                     varchar(100)                   not null,
   nom_fantas                     varchar(100),
   primary key (id_empres)
)
type = InnoDB;

/*==============================================================*/
/* Index: ix_empresa                                            */
/*==============================================================*/
create unique index ix_empresa on fc_empresa
(
   nom_empres
);

/*==============================================================*/
/* Table: fc_entidade_financeira                                */
/*==============================================================*/
create table if not exists fc_entidade_financeira
(
   id_entid_financ                int(11)                        not null AUTO_INCREMENT,
   num_agenc                      varchar(8)                     not null,
   num_conta                      varchar(10)                    not null,
   num_conv                       varchar(16),
   num_oper                       varchar(10),
   des_instruc                    text,
   num_cart                       varchar(10),
   sub_cartei                     varchar(10),
   esp_doc                        varchar(5),
   num_banco                      varchar(8)                     not null,
   nom_entid                      varchar(100)                   not null,
   tipo_entid                     varchar(50)                    not null,
   cod_cedente                    varchar(20),
   idc_aceite                     char(1),
   dig_conta                      char(3),
   dig_agencia                    char(3),
   num_sequencial                 int(10) unsigned,
   primary key (id_entid_financ)
)
type = InnoDB;

/*==============================================================*/
/* Table: fc_fabricante                                         */
/*==============================================================*/
create table if not exists fc_fabricante
(
   id_fabric                      int(11)                        not null AUTO_INCREMENT,
   nom_fabric                     varchar(100)                   not null,
   primary key (id_fabric)
)
type = InnoDB;

/*==============================================================*/
/* Index: ix_fabricante                                         */
/*==============================================================*/
create unique index ix_fabricante on fc_fabricante
(
   nom_fabric
);

/*==============================================================*/
/* Table: fc_forma_pagamento                                    */
/*==============================================================*/
create table if not exists fc_forma_pagamento
(
   id_forma_pagto                 int(11)                        not null AUTO_INCREMENT,
   des_forma_pagto                varchar(50)                    not null,
   idc_forma_pagto                char(1)                        not null,
   primary key (id_forma_pagto)
)
type = InnoDB;

/*==============================================================*/
/* Index: ix_descricao                                          */
/*==============================================================*/
create unique index ix_descricao on fc_forma_pagamento
(
   des_forma_pagto
);

/*==============================================================*/
/* Table: fc_frete                                              */
/*==============================================================*/
create table if not exists fc_frete
(
   id_frete                       int(11)                        not null AUTO_INCREMENT,
   nom_empres                     varchar(100)                   not null,
   nom_servic                     varchar(50),
   idc_dispon                     char(1)                        not null,
   primary key (id_frete)
)
type = InnoDB;

/*==============================================================*/
/* Index: ix_frete                                              */
/*==============================================================*/
create unique index ix_frete on fc_frete
(
   nom_empres,
   nom_servic
);

/*==============================================================*/
/* Table: fc_frete_estado                                       */
/*==============================================================*/
create table if not exists fc_frete_estado
(
   id_frete                       int(11)                        not null,
   nom_estado_destin              char(2)                        not null,
   pes_produt                     numeric(10,4)                  not null,
   val_frete_capitl               numeric(14,2)                  not null,
   val_frete_interi               numeric(14,2)                  not null,
   tmp_entreg_capitl              int(5) unsigned,
   tmp_entreg_interi              int(5) unsigned,
   primary key (id_frete, nom_estado_destin, pes_produt),
    index(id_frete), foreign key (`id_frete`)
                  references `fc_frete` (`id_frete`)
                              
                              on delete cascade
)
type = InnoDB;

/*==============================================================*/
/* Table: fc_moeda                                              */
/*==============================================================*/
create table if not exists fc_moeda
(
   id_moeda                       int(11)                        not null AUTO_INCREMENT,
   tip_moeda                      char(8)                        not null,
   sim_moeda                      char(4)                        not null,
   cot_moeda                      numeric(10,4),
   dt_cotacao                     date,
   primary key (id_moeda)
)
type = InnoDB;

/*==============================================================*/
/* Index: ix_moeda                                              */
/*==============================================================*/
create unique index ix_moeda on fc_moeda
(
   tip_moeda,
   sim_moeda
);

/*==============================================================*/
/* Table: fc_pais                                               */
/*==============================================================*/
create table if not exists fc_pais
(
   sig_pais                       varchar(5)                     not null,
   nom_pais                       varchar(255),
   primary key (sig_pais)
)
type = InnoDB;

/*==============================================================*/
/* Table: fc_parcelamento                                       */
/*==============================================================*/
create table if not exists fc_parcelamento
(
   id_parcel                      int(11)                        not null AUTO_INCREMENT,
   des_parcel                     varchar(20)                    not null,
   val_juros                      numeric(4,2)                   not null,
   idc_dispon                     char(1)                        not null,
   primary key (id_parcel)
)
type = InnoDB;

/*==============================================================*/
/* Index: ix01                                                  */
/*==============================================================*/
create unique index ix01 on fc_parcelamento
(
   des_parcel,
   val_juros
);

/*==============================================================*/
/* Table: fc_pessoa                                             */
/*==============================================================*/
create table if not exists fc_pessoa
(
   id_pessoa                      int(11)                        not null AUTO_INCREMENT,
   des_ender                      varchar(100),
   des_complm                     varchar(25),
   nom_bairro                     varchar(25),
   num_cep                        varchar(10),
   num_telef1                     varchar(20),
   num_telef2                     varchar(20),
   num_telef3                     varchar(20),
   num_fax                        varchar(20),
   nom_cidade                     varchar(25),
   sig_estado                     char(2),
   nom_pais                       varchar(255),
   des_ender_cobran               varchar(100),
   des_complm_cobran              varchar(25),
   nom_bairro_cobran              varchar(25),
   num_cep_cobran                 varchar(10),
   nom_cidade_cobran              varchar(25),
   sig_estado_cobran              char(2),
   nom_pais_cobran                varchar(255),
   des_refer_entreg               varchar(100),
   des_ender_entreg               varchar(100),
   des_complm_entreg              varchar(25),
   nom_bairro_entreg              varchar(25),
   num_cep_entreg                 varchar(10),
   nom_cidade_entreg              varchar(25),
   sig_estado_entreg              char(2),
   nom_pais_entreg                varchar(255),
   primary key (id_pessoa)
)
type = InnoDB;

/*==============================================================*/
/* Table: fc_pessoa_fisica                                      */
/*==============================================================*/
create table if not exists fc_pessoa_fisica
(
   id_pessoa                      int(11)                        not null,
   num_cpf                        char(12),
   nom_client                     varchar(50)                    not null,
   num_ident                      varchar(20),
   dt_nascim                      date,
   tip_sexo                       char(1),
   stt_estado_civil               char(2),
   idc_recebt_mail                char(1),
   num_celula                     varchar(20),
   idc_acesso                     char(1),
   primary key (id_pessoa),
    index(id_pessoa), foreign key (`id_pessoa`)
                  references `fc_pessoa` (`id_pessoa`)                              
                              on delete cascade
)
type = InnoDB;

/*==============================================================*/
/* Index: ix_cpf                                                */
/*==============================================================*/
create unique index ix_cpf on fc_pessoa_fisica
(
   num_cpf
);

/*==============================================================*/
/* Table: fc_pessoa_juridica                                    */
/*==============================================================*/
create table if not exists fc_pessoa_juridica
(
   id_pessoa                      int(11)                        not null,
   num_cnpj                       varchar(16)                    not null,
   id_empres                      int(11)                        not null,
   insc_est                       varchar(20)                    not null,
   primary key (id_pessoa),
    index(id_empres), foreign key (`id_empres`)
                  references `fc_empresa` (`id_empres`)
                              
                              on delete cascade,
    index(id_pessoa), foreign key (`id_pessoa`)
                  references `fc_pessoa` (`id_pessoa`)
                              
                              on delete cascade
)
type = InnoDB;

/*==============================================================*/
/* Index: ix_cnpj                                               */
/*==============================================================*/
create unique index ix_cnpj on fc_pessoa_juridica
(
   num_cnpj
);

/*==============================================================*/
/* Table: fc_unidade_medida                                     */
/*==============================================================*/
create table if not exists fc_unidade_medida
(
   id_unid                        int(11)                        not null AUTO_INCREMENT,
   cod_unid                       char(8)                        not null,
   des_unid                       varchar(25)                    not null,
   primary key (id_unid)
)
type = InnoDB;

/*==============================================================*/
/* Index: ix_unidade                                            */
/*==============================================================*/
create unique index ix_unidade on fc_unidade_medida
(
   cod_unid,
   des_unid
);

/*==============================================================*/
/* Table: fc_usuario                                            */
/*==============================================================*/
create table if not exists fc_usuario
(
   id_login                       varchar(15)                    not null,
   nom_usuar                      varchar(50)                    not null,
   id_senha                       varchar(32)                    not null,
   des_email                      varchar(100),
   primary key (id_login)
)
type = InnoDB;

/*==============================================================*/
/* Table: fc_log_usuario                                        */
/*==============================================================*/
create table if not exists fc_log_usuario
(
   id_login                       varchar(15)                    not null,
   dat_acao                       datetime                       not null,
   primary key (dat_acao, id_login),
    index(id_login), foreign key (`id_login`)
                  references `fc_usuario` (`id_login`)
                              
                              on delete restrict
)
type = InnoDB;

/*==============================================================*/
/* Table: fc_loja                                               */
/*==============================================================*/
create table if not exists fc_loja
(
   id_loja                        int(11)                        not null AUTO_INCREMENT,
   tip_loja                       varchar(1)                     not null,
   nom_loja                       varchar(50),
   nom_empres                     varchar(100)                   not null,
   txa_presen                     numeric(14,2),
   des_ender                      varchar(100),
   des_complm                     varchar(25),
   nom_bairro                     varchar(25),
   num_cep                        varchar(9),
   nom_cidade                     varchar(25),
   sig_estado                     char(2),
   nom_pais                       varchar(255),
   num_telef1                     varchar(20),
   num_telef2                     varchar(20),
   num_fax                        varchar(20),
   loj_ativa                      char(1)                        not null default 'N',
   des_email                      varchar(100),
   des_venda                      mediumtext,
   idc_estoq_negati               char(1)                        not null,
   id_moeda                       int(11)                        not null,
   site_empres                    varchar(255),
   des_acesso                     mediumtext,
   des_info_inicial               mediumtext,
   prod_pagina                    int(11),
   num_cnpj                       varchar(16),
   cor_fundo_logo                 varchar(10),
   cor_fundo_menu                 varchar(10),
   cor_titulo_produto             varchar(10),
   cor_preco_produto              varchar(10),
   cor_link                       varchar(10),
   smtp_endereco                  varchar(255)                   not null,
   smtp_senha                     varchar(32)                    not null,
   apagar_num_cartao              char(1)                        not null,
   id_imagem                   bigint(10) UNSIGNED,
   primary key (id_loja),
    index(id_moeda), foreign key (`id_moeda`)
                  references `fc_moeda` (`id_moeda`)
)
type = InnoDB;

/*==============================================================*/
/* Table: fc_parcela                                            */
/*==============================================================*/
create table if not exists fc_parcela
(
   id_parcel                      int(11)                        not null,
   num_dias                       int                            not null,
   val_perc_parcel                numeric(4,2)                   not null,
   primary key (id_parcel, num_dias),
    index(id_parcel), foreign key (`id_parcel`)
                  references `fc_parcelamento` (`id_parcel`)
                             on delete cascade
)
type = InnoDB;

/*==============================================================*/
/* Table: fc_estados                                            */
/*==============================================================*/
create table if not exists fc_estados
(
   sig_estado                     char(2)                        not null,
   nom_estado                     varchar(25)                    not null,
   sig_pais                       char(5)                        not null,
   primary key (sig_estado),
    index(sig_pais), foreign key (`sig_pais`)
                  references `fc_pais` (`sig_pais`)
                              on update restrict
                              on delete restrict
)
type = InnoDB;

/*==============================================================*/
/* Table: fc_cidades_br                                         */
/*==============================================================*/
create table if not exists fc_cidades_br
(
   sig_estado                     char(2)                        not null,
   nom_cidade                     varchar(70)                    not null,
   des_categ                      varchar(12),
   md_latide                      float(12,31),
   md_longde                      float(12,31),
   md_altide                      float(12,31),
   cod_cidade                     int(11),
   primary key (sig_estado, nom_cidade),
    index(sig_estado), foreign key (`sig_estado`)
                  references `fc_estados` (`sig_estado`)
                              on update restrict
                              on delete restrict
)
type = InnoDB;

/*==============================================================*/
/* Index: ix_cidade                                             */
/*==============================================================*/
create unique index ix_cidade on fc_cidades_br
(
   sig_estado,
   nom_cidade
);

/*==============================================================*/
/* Table: fc_comprador                                          */
/*==============================================================*/
create table if not exists fc_comprador
(
   id_comprador                   int(11)                        not null,
   id_login                       varchar(100)                   not null,
   id_senha                       varchar(32)                    not null,
   primary key (id_comprador),
    index(id_comprador), foreign key (`id_comprador`)
                  references `fc_pessoa_fisica` (`id_pessoa`)
                              
                              on delete cascade
)
type = InnoDB;

/*==============================================================*/
/* Index: ix_login                                              */
/*==============================================================*/
create unique index ix_login on fc_comprador
(
   id_login
);

/*==============================================================*/
/* Table: fc_produto                                            */
/*==============================================================*/
create table if not exists fc_produto
(
   id_produt                      int(11)                        not null AUTO_INCREMENT,
   cod_produt                   varchar(8)                     not null,
   nom_produt                  varchar(50)                    not null,
   des_produt                   varchar(255),
   cod_classe                   varchar(40)                    not null,
   id_unid                           int(11)                        not null,
   id_fabric                        int(11)                        not null,
   id_moeda                       int(11)                        not null,
   pes_produt                    numeric(10,4)                  not null,
   idc_presen                    char(1)                        not null,
   pre_produt                     numeric(14,2)                  not null,
   qtd_limite_cli                  numeric(10,4),
   qtd_estoq                      numeric(10,4),
   qtd_minima                     numeric(10,4),
   pre_ofert                        numeric(14,2),
   dt_valid                           date,
   idc_dispon                      char(1),
   id_imagem1                     BIGINT(10) UNSIGNED,
   id_imagem2                     BIGINT(10) UNSIGNED,
   id_imagem3                     BIGINT(10) UNSIGNED,
   id_imagem4                     BIGINT(10) UNSIGNED,
   id_imagem5                     BIGINT(10) UNSIGNED,
   prod_destaque               char(1),
   primary key (id_produt),
    index(cod_classe), foreign key (`cod_classe`)
                  references `fc_classe_produto` (`cod_classe`)
                              
                              on delete restrict,
    index(id_unid), foreign key (`id_unid`)
                  references `fc_unidade_medida` (`id_unid`)
                              on update cascade
                              on delete restrict,
    index(id_fabric), foreign key (`id_fabric`)
                  references `fc_fabricante` (`id_fabric`)
                              
                              on delete restrict,
    index(id_moeda), foreign key (`id_moeda`)
                  references `fc_moeda` (`id_moeda`)
                              on update restrict
                              on delete restrict
)
type = InnoDB;

/*==============================================================*/
/* Index: ix_produto                                            */
/*==============================================================*/
create unique index ix_produto on fc_produto
(
   nom_produt
);

/*==============================================================*/
/* Index: ix_codigo                                             */
/*==============================================================*/
create unique index ix_codigo on fc_produto
(
   cod_produt
);

/*==============================================================*/
/* Table: fc_condicao                                           */
/*==============================================================*/
create table if not exists fc_condicao
(
   id_condic                      int(11)                        not null AUTO_INCREMENT,
   id_entid_financ                int(11)                        not null,
   id_forma_pagto                 int(11)                        not null,
   id_parcel                      int(11)                        not null,
   idc_dispon                     char(1)                        not null,
   primary key (id_condic),
    index(id_forma_pagto), foreign key (`id_forma_pagto`)
                  references `fc_forma_pagamento` (`id_forma_pagto`)
                              
                              on delete restrict,
    index(id_entid_financ), foreign key (`id_entid_financ`)
                  references `fc_entidade_financeira` (`id_entid_financ`)
                              
                              on delete restrict,
    index(id_parcel), foreign key (`id_parcel`)
                  references `fc_parcelamento` (`id_parcel`)
                              
                              on delete restrict
)
type = InnoDB;

/*==============================================================*/
/* Index: ix_condicao                                           */
/*==============================================================*/
create unique index ix_condicao on fc_condicao
(
   id_entid_financ,
   id_forma_pagto,
   id_parcel
);

/*==============================================================*/
/* Table: fc_movto_estoq                                        */
/*==============================================================*/
create table if not exists fc_movto_estoq
(
   seq_movto                      int(10) unsigned               not null AUTO_INCREMENT,
   id_login                       varchar(15)                    not null,
   id_produt                      int(11)                        not null,
   qtd_produt                     numeric(10,4)                  not null,
   dt_movto                       date                           not null,
   idc_movto                      char(1),
   primary key (seq_movto),
    index(id_produt), foreign key (`id_produt`)
                  references `fc_produto` (`id_produt`)
                              
                              on delete restrict,
    index(id_login), foreign key (`id_login`)
                  references `fc_usuario` (`id_login`)
                              
                              on delete restrict
)
type = InnoDB;

/*==============================================================*/
/* Table: fc_aut_compra                                         */
/*==============================================================*/
create table if not exists fc_aut_compra
(
   id_pessoa                      int(11)                        not null,
   id_aut_compra                  int(11)                        not null AUTO_INCREMENT,
   id_comprador                   int(11)                        not null,
   primary key (id_aut_compra),
    index(id_pessoa), foreign key (`id_pessoa`)
                  references `fc_pessoa` (`id_pessoa`)
                              
                              on delete cascade,
    index(id_comprador), foreign key (`id_comprador`)
                  references `fc_comprador` (`id_comprador`)
                              
                              on delete cascade
)
type = InnoDB;

/*==============================================================*/
/* Index: ix_autorizacao                                        */
/*==============================================================*/
create unique index ix_autorizacao on fc_aut_compra
(
   id_pessoa,
   id_comprador
);

/*==============================================================*/
/* Table: fc_caract_produto                                     */
/*==============================================================*/
create table if not exists fc_caract_produto
(
   id_carac                       int(11)                        not null AUTO_INCREMENT,
   id_produt                      int(11)                        not null,
   des_titulo                     varchar(25)                    not null,
   des_carac                      varchar(255),
   idc_destaq                     char(1)                        not null default 'n',
   primary key (id_carac),
    index(id_produt), foreign key (`id_produt`)
                  references `fc_produto` (`id_produt`)
                              
                              on delete cascade
)
type = InnoDB;

/*==============================================================*/
/* Table: fc_log_comprador                                      */
/*==============================================================*/
create table if not exists fc_log_comprador
(
   id_comprador                   int(11)                        not null,
   dat_acao                       datetime                       not null,
   primary key (dat_acao, id_comprador),
    index(id_comprador), foreign key (`id_comprador`)
                  references `fc_comprador` (`id_comprador`)
                              
                              on delete restrict
)
type = InnoDB;

/*==============================================================*/
/* Table: fc_pedido                                             */
/*==============================================================*/
create table if not exists fc_pedido
(
   num_pedido                     int(11)                        not null AUTO_INCREMENT,
   dat_pedido                     date                           not null,
   val_frete                      numeric(14,2)                  not null,
   id_frete                       int(11)                        not null,
   id_aut_compra                  int(11)                        not null,
   id_condic                      int(11)                        not null,
   des_ender_entreg               varchar(100)                   not null,
   des_complm_entreg              varchar(25),
   nom_bairro_entreg              varchar(25),
   num_cep_entreg                 varchar(9)                     not null,
   nom_cidade_entreg              varchar(25)                    not null,
   sig_estado_entreg              char(2)                        not null,
   nom_pais_entreg                varchar(255)                   not null,
   nom_destno_entreg              varchar(50),
   des_refer                      varchar(150),
   num_cartao                     varchar(32),
   cod_identf                     char(4),
   dt_valid                       varchar(7),
   nom_usuar_cartao               varchar(50),
   dt_nasc                        varchar(10),
   vlr_pedido                     numeric(14,2)                 not null,
   importado_business             varchar(1)                    not null,
   hora_pedido                    time                          not null,
   primary key (num_pedido),
    index(id_aut_compra), foreign key (`id_aut_compra`)
                  references `fc_aut_compra` (`id_aut_compra`)
                              
                              on delete restrict,
    index(id_frete), foreign key (`id_frete`)
                  references `fc_frete` (`id_frete`)
                              
                              on delete restrict,
    index(id_condic), foreign key (`id_condic`)
                  references `fc_condicao` (`id_condic`)
                              
                              on delete restrict
)
type = InnoDB;

/*==============================================================*/
/* Table: fc_boleto_gerado                                      */
/*==============================================================*/
create table if not exists fc_boleto_gerado
(
   id_entid_financ                int(11)                        not null,
   num_pedido                     int(11)                        not null,
   dt_vencim                      date                           not null,
   id_nosso_numero                int(11) unsigned               not null,
   vlr_boleto                     numeric(14,2),
   primary key (id_entid_financ, num_pedido, id_nosso_numero),
    index(id_nosso_numero),
    index(id_entid_financ), foreign key (`id_entid_financ`)
                  references `fc_entidade_financeira` (`id_entid_financ`)
                              on update restrict
                              on delete restrict,
    index(num_pedido), foreign key (`num_pedido`)
                  references `fc_pedido` (`num_pedido`)
                              on update restrict
                              on delete restrict 
)
type = InnoDB;

/*==============================================================*/
/* Table: fc_item_pedido                                        */
/*==============================================================*/
create table if not exists fc_item_pedido
(
   num_pedido                     int(11)                        not null,
   seq_item                       int(10) unsigned               not null,
   id_produt                      int(11)                        not null,
   qtd_produt                     numeric(10,4)                  not null,
   pre_produt                     numeric(14,2)                  not null,
   sit_item                       char(1)                        not null,
   tip_moeda                      char(8)                        not null,
   primary key (num_pedido, seq_item),
    index(num_pedido), foreign key (`num_pedido`)
                  references `fc_pedido` (`num_pedido`)
                              
                              on delete cascade,
    index(id_produt), foreign key (`id_produt`)
                  references `fc_produto` (`id_produt`)
                              
                              on delete restrict
)
type = InnoDB;

/*==============================================================*/
/* Table: fc_imagem                                             */
/*==============================================================*/
CREATE TABLE fc_imagem
 (
   id_imagem        BIGINT(10) UNSIGNED NOT NULL AUTO_INCREMENT, 
   imagem             BLOB NOT NULL, 
   tipo_imagem     VARCHAR(15) NOT NULL, 
   ultima_Modif     BIGINT(20) UNSIGNED DEFAULT 0  NOT NULL,
   PRIMARY KEY (id_imagem)
) TYPE = InnoDB; 



/*==============================================================*/
/*#                  Link Pessoa Fsica                            #*/
/**==============================================================*/

/*==============================================================*/
/* Table: fc_link_pessoa_fisica                                 */
/*==============================================================*/
create table if not exists fc_link_pessoa_fisica
(
   id_pessoa_fc                   int(11)                        not null,
   id_pessoa_bu                   int(11)                        not null,
   id_endereco_bu                 int(11)                        not null,
   id_contato_bu                  int(11)                        not null,
   primary key (id_pessoa_fc, id_pessoa_bu, id_endereco_bu, id_contato_bu)
)
type = InnoDB;

/*==============================================================*/
/* Index: pf_fc                                                 */
/*==============================================================*/
create unique index pf_fc on fc_link_pessoa_fisica
(
   id_pessoa_fc
);

/*==============================================================*/
/* Index: pf_bu                                                 */
/*==============================================================*/
create unique index pf_bu on fc_link_pessoa_fisica
(
   id_pessoa_bu,
   id_endereco_bu,
   id_contato_bu
);

/*==============================================================*/
/*#                   Link Pessoa Jurdica                         #*/
/*==============================================================*/

/*==============================================================*/
/* Table: fc_link_pessoa_juridica                               */
/*==============================================================*/
create table if not exists fc_link_pessoa_juridica
(
   id_pessoa_fc                   int(11)                        not null,
   id_pessoa_bu                   int(11)                        not null,
   id_endereco_bu                 int(11)                        not null,
   primary key (id_pessoa_fc, id_pessoa_bu, id_endereco_bu)
)
type = InnoDB;

/*==============================================================*/
/* Index: pj_fc                                                 */
/*==============================================================*/
create unique index pj_fc on fc_link_pessoa_juridica
(
   id_pessoa_fc
);

/*==============================================================*/
/* Index: pj_bu                                                 */
/*==============================================================*/
create unique index pj_bu on fc_link_pessoa_juridica
(
   id_pessoa_bu,
   id_endereco_bu
);

/*==============================================================*/
/*#                      Link Produto                              #*/
/*==============================================================*/

/*==============================================================*/
/* Table: fc_link_produto                                       */
/*==============================================================*/
create table if not exists fc_link_produto
(
   id_produto_fc                   int(11)                        not null,
   id_produto_bu                   int(11)                        not null,
   primary key (id_produto_fc, id_produto_bu)
)
type = InnoDB;

/*==============================================================*/
/* Index: produto_fc                                            */
/*==============================================================*/
create unique index produto_fc on fc_link_produto
(
   id_produto_fc
);

/*==============================================================*/
/* Index: produto_bu                                            */
/*==============================================================*/
create unique index produto_bu on fc_link_produto
(
   id_produto_bu
);